# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/noise_filter.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(258, 215)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(30, 180, 221, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayoutWidget = QtWidgets.QWidget(parent=Dialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 241, 167))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.verticalLayoutWidget)
        self.gridLayout_9.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.red_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.red_slider.setMinimum(0)
        self.red_slider.setMaximum(1000)
        self.red_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.red_slider.setObjectName("red_slider")
        self.gridLayout_8.addWidget(self.red_slider, 1, 0, 1, 1)
        self.red_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.red_spinbox.setMinimum(0.0)
        self.red_spinbox.setMaximum(1.0)
        self.red_spinbox.setSingleStep(0.01)
        self.red_spinbox.setObjectName("red_spinbox")
        self.gridLayout_8.addWidget(self.red_spinbox, 1, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_8.setObjectName("label_8")
        self.gridLayout_8.addWidget(self.label_8, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_8, 0, 0, 1, 1)
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.green_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.green_slider.setMinimum(0)
        self.green_slider.setMaximum(1000)
        self.green_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.green_slider.setObjectName("green_slider")
        self.gridLayout_7.addWidget(self.green_slider, 1, 0, 1, 1)
        self.green_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.green_spinbox.setMinimum(0.0)
        self.green_spinbox.setMaximum(1.0)
        self.green_spinbox.setSingleStep(0.01)
        self.green_spinbox.setObjectName("green_spinbox")
        self.gridLayout_7.addWidget(self.green_spinbox, 1, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_7.setObjectName("label_7")
        self.gridLayout_7.addWidget(self.label_7, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_7, 1, 0, 1, 1)
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.blue_slider = QtWidgets.QSlider(parent=self.verticalLayoutWidget)
        self.blue_slider.setMinimum(0)
        self.blue_slider.setMaximum(1000)
        self.blue_slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.blue_slider.setObjectName("blue_slider")
        self.gridLayout_6.addWidget(self.blue_slider, 1, 0, 1, 1)
        self.blue_spinbox = QtWidgets.QDoubleSpinBox(parent=self.verticalLayoutWidget)
        self.blue_spinbox.setMinimum(0.0)
        self.blue_spinbox.setMaximum(1.0)
        self.blue_spinbox.setSingleStep(0.01)
        self.blue_spinbox.setObjectName("blue_spinbox")
        self.gridLayout_6.addWidget(self.blue_spinbox, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(parent=self.verticalLayoutWidget)
        self.label_6.setObjectName("label_6")
        self.gridLayout_6.addWidget(self.label_6, 0, 0, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_6, 2, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Color Balance"))
        self.label_8.setText(_translate("Dialog", "Red"))
        self.label_7.setText(_translate("Dialog", "Green"))
        self.label_6.setText(_translate("Dialog", "Blue"))
