# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/header.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_header(object):
    def setupUi(self, header):
        header.setObjectName("header")
        header.resize(970, 50)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(header.sizePolicy().hasHeightForWidth())
        header.setSizePolicy(sizePolicy)
        header.setMinimumSize(QtCore.QSize(0, 0))
        header.setMaximumSize(QtCore.QSize(16777215, 68))
        self.gridLayout = QtWidgets.QGridLayout(header)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.frame = QtWidgets.QFrame(parent=header)
        self.frame.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.undo_button = QtWidgets.QPushButton(parent=self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.undo_button.sizePolicy().hasHeightForWidth())
        self.undo_button.setSizePolicy(sizePolicy)
        self.undo_button.setMinimumSize(QtCore.QSize(0, 0))
        self.undo_button.setMaximumSize(QtCore.QSize(40, 40))
        self.undo_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.undo_button.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/007-undo.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.undo_button.setIcon(icon)
        self.undo_button.setIconSize(QtCore.QSize(24, 24))
        self.undo_button.setFlat(True)
        self.undo_button.setObjectName("undo_button")
        self.gridLayout_2.addWidget(self.undo_button, 0, 4, 1, 1)
        self.redo_button = QtWidgets.QPushButton(parent=self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.redo_button.sizePolicy().hasHeightForWidth())
        self.redo_button.setSizePolicy(sizePolicy)
        self.redo_button.setMinimumSize(QtCore.QSize(0, 0))
        self.redo_button.setMaximumSize(QtCore.QSize(40, 40))
        self.redo_button.setStyleSheet("border-color: rgb(61, 56, 70);")
        self.redo_button.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/008-redo.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.redo_button.setIcon(icon1)
        self.redo_button.setIconSize(QtCore.QSize(24, 24))
        self.redo_button.setFlat(True)
        self.redo_button.setObjectName("redo_button")
        self.gridLayout_2.addWidget(self.redo_button, 0, 5, 1, 1)
        self.save_button = QtWidgets.QPushButton(parent=self.frame)
        self.save_button.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/033-diskette.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.save_button.setIcon(icon2)
        self.save_button.setIconSize(QtCore.QSize(24, 24))
        self.save_button.setFlat(True)
        self.save_button.setObjectName("save_button")
        self.gridLayout_2.addWidget(self.save_button, 0, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 0, 6, 1, 1)
        self.file_new_button = QtWidgets.QPushButton(parent=self.frame)
        self.file_new_button.setMaximumSize(QtCore.QSize(40, 40))
        self.file_new_button.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/036-new-document.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.file_new_button.setIcon(icon3)
        self.file_new_button.setIconSize(QtCore.QSize(24, 24))
        self.file_new_button.setFlat(True)
        self.file_new_button.setObjectName("file_new_button")
        self.gridLayout_2.addWidget(self.file_new_button, 0, 0, 1, 1)
        self.open_button = QtWidgets.QPushButton(parent=self.frame)
        self.open_button.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/../../src/icons/034-folder.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.open_button.setIcon(icon4)
        self.open_button.setIconSize(QtCore.QSize(24, 24))
        self.open_button.setFlat(True)
        self.open_button.setObjectName("open_button")
        self.gridLayout_2.addWidget(self.open_button, 0, 1, 1, 1)
        self.gridLayout.addWidget(self.frame, 0, 0, 1, 1)

        self.retranslateUi(header)
        QtCore.QMetaObject.connectSlotsByName(header)

    def retranslateUi(self, header):
        _translate = QtCore.QCoreApplication.translate
        header.setWindowTitle(_translate("header", "Form"))
        self.undo_button.setToolTip(_translate("header", "Undo"))
        self.redo_button.setToolTip(_translate("header", "Redo"))
