# Form implementation generated from reading ui file '/home/joe/Projects/imagetopixel/airunner/src/airunner/pyqt/widgets/lora_container.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(583, 775)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.toggleAllLora = QtWidgets.QCheckBox(parent=Form)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.toggleAllLora.setFont(font)
        self.toggleAllLora.setChecked(False)
        self.toggleAllLora.setTristate(False)
        self.toggleAllLora.setObjectName("toggleAllLora")
        self.gridLayout.addWidget(self.toggleAllLora, 0, 0, 1, 1)
        self.lora_scroll_area = QtWidgets.QScrollArea(parent=Form)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.lora_scroll_area.setFont(font)
        self.lora_scroll_area.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
        self.lora_scroll_area.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.lora_scroll_area.setWidgetResizable(True)
        self.lora_scroll_area.setObjectName("lora_scroll_area")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 583, 755))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.lora_scroll_area.setWidget(self.scrollAreaWidgetContents_2)
        self.gridLayout.addWidget(self.lora_scroll_area, 1, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.toggleAllLora.setText(_translate("Form", "Toggle all"))
